

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Finds the absorption coeffiecient of water vapor, carbon dioxide, nitrogen, and oxygen molecules
%based on Hitran database and VVW line shape model
%Inputs:
%   -Freq: The frequency array
%   -rh: relative humidity of the channel
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [total_absorption] = absorption(Freq, rh)
c = 2.997925e8;  %light velocity m/s
v = (Freq./c) .*0.01; %wavenumber of each correspond frequency in cm^(-1)

% T in kelvin, pd and  pw in pa
p = 101325; %pressure in pa
p_sat = 24.8680; % millibar  saturation pressure for T = 21 C, based on equation p_sat = 6.1078*10^(7.5T/(T+237.3))
pv = rh/100 * p_sat; %millibar
pv = pv *100; %pressure of water vapor in pa
pd = p - pv; %pressure of dry air in pa
T = 296; %temperature in Kelvin 


%Water absorption---------------------
if(rh ~= 0)
    data = importdata('AbsorptionTable/water_hitran.txt');
    
    %volume mixing ratio
    q_water_vapor = (0.622*pv)/(pd);
    
    v0_water = data(:, 1).';
    s_water = data(:, 2).';
    a_water_air = data(:, 4).';
    a_water_self = data(:, 5).';
    
    a_water = (1-q_water_vapor).* a_water_air + q_water_vapor.* a_water_self;
    
    
    for v_ind = 1: length(v)
        k_water(v_ind) = 0;
        ind = 1;
        for ind = 1:length(v0_water)
            %VVW line shape
            k_water(v_ind) = k_water(v_ind)+(s_water(ind)/pi)*(v(v_ind)/v0_water(ind))^2*...
                (a_water(ind)/((v(v_ind)-v0_water(ind))^2 + (a_water(ind))^2) + a_water(ind)/((v(v_ind)+v0_water(ind))^2 + a_water(ind)^2));
        end
    end
    
    % humid air density from wikipedia: http://en.wikipedia.org/wiki/Density_of_air
    Mv =  0.018016;
    R = 8.314;
    avogadro = 6.02214129e+23;
    vapor_density = (pv*Mv)/(R*T); % unit kg/m3 --> 1 gr water = 0.0555084350618 moles
    vapor_density = vapor_density*0.001*0.0555084350618*avogadro; % molecules/cm3
    
    
    water_absorption_coeff = vapor_density.* k_water;
    
end
%Oxygen absorption---------------------
data_oxygen= importdata('AbsorptionTable/oxygen_hitran.txt');

v0_oxygen = data_oxygen(:, 1).';
s_oxygen = data_oxygen(:, 2).';
a_oxygen_air = data_oxygen(:, 4).';
a_oxygen_self = data_oxygen(:, 5).';
q_oxygen = 0.21;
a_oxygen = (1-q_oxygen).* a_oxygen_air + q_oxygen.* a_oxygen_self;

for v_ind = 1: length(v)
    k_oxygen(v_ind) = 0;
    for ind = 1:length(v0_oxygen)
        k_oxygen(v_ind) = k_oxygen(v_ind)+(s_oxygen(ind)/pi)*(v(v_ind)/v0_oxygen(ind))^2*(a_oxygen(ind)/((v(v_ind)-v0_oxygen(ind))^2 + a_oxygen(ind)^2) + a_oxygen(ind)/((v(v_ind)+v0_oxygen(ind))^2 + a_oxygen(ind)^2));
    end
end

oxygen_density = 4.923e19; %molecules/cm3
oxygen_absorption = oxygen_density.*k_oxygen ;

% N2 absorption ---------------------------------------------------------
data_N2= importdata('AbsorptionTable/N2_hitran.txt');

v0_N2 = data_N2(:, 1).';
s_N2 = data_N2(:, 2).';
a_N2_air = data_N2(:, 4).';
a_N2_self = data_N2(:, 5).';
q_N2 = 78.084*0.01;
a_N2 = (1-q_N2).* a_N2_air + q_N2.* a_N2_self;


for v_ind = 1: length(v)
    k_N2(v_ind) = 0;
    for ind = 1:length(v0_N2)
        k_N2(v_ind) = k_N2(v_ind)+(s_N2(ind)/pi)*(v(v_ind)/v0_N2(ind))^2*(a_N2(ind)/((v(v_ind)-v0_N2(ind))^2 + a_N2(ind)^2) + a_N2(ind)/((v(v_ind)+v0_N2(ind))^2 + a_N2(ind)^2));
    end
end

% N2_density = 0.0638* 0.001* avogadro;%molecules/cm3
N2_density = 4.9229e19;
N2_absorption = N2_density.* k_N2 ;%molecules/cm3

% co2 absorption ---------------------------------------------------------
data_co2= importdata('AbsorptionTable/co2_hitran.txt');

v0_co2 = data_co2(:, 1).';
s_co2 = data_co2(:, 2).';
a_co2_air = data_co2(:, 4).';
a_co2_self = data_co2(:, 5).';

q_co2 = 0.035*0.01;

a_co2 = (1-q_co2).* a_co2_air + q_co2.* a_co2_self;


for v_ind = 1: length(v)
    k_co2(v_ind) = 0;
    for ind = 1:length(v0_co2)
        k_co2(v_ind) = k_co2(v_ind)+(s_co2(ind)/pi)*(v(v_ind)/v0_co2(ind))^2*(a_co2(ind)/((v(v_ind)-v0_co2(ind))^2 + a_co2(ind)^2) + a_co2(ind)/((v(v_ind)+v0_co2(ind))^2 + a_co2(ind)^2));
    end
end

co2_density= 2.4617e19; %molecules/cm3
co2_absorption = co2_density.* k_co2;

%TOTAL ABSORPTION -------------------
if(rh ~= 0)
    %absorption coefficient when rh>0
    total_absorption = oxygen_absorption + water_absorption_coeff + N2_absorption + co2_absorption;
else
    %absorption coefficient when rh=0 
    total_absorption = oxygen_absorption + co2_absorption + N2_absorption;
end


end





